/**
 * An Mirf example which copies back the data it recives.
 * While wating the arduino goes to sleep and will be woken up
 * by the interupt pin of the mirf.
 * 
 * Warning: Due to the sleep mode the Serial output donsn't work.
 *
 * Pins:
 * Hardware SPI:
 * MISO -> 12
 * MOSI -> 11
 * SCK -> 13
 *
 * Configurable:
 * CE -> 8
 * CSN -> 7
 */

#include <SPI.h>
#include <Mirf.h>
#include <nRF24L01.h>
#include <MirfHardwareSpiDriver.h>
#include <avr/sleep.h>

volatile boolean winner = false;
int led = 4;
int buzzer = 5;
int button = 3;

void someoneBuzz(){
}

void iBuzz(){
    winner = true;
}

void toSleep(){
  if (EIFR & (1 << 0)) EIFR |= 1 << 0; // reset interrupt register 0
  attachInterrupt(0,someoneBuzz,LOW);
  if (EIFR & (1 << 1)) EIFR |= 1 << 1; // reset interrupt register 1
  attachInterrupt(1,iBuzz,RISING);
  sleep_mode();
  detachInterrupt(0);
  detachInterrupt(1);
}

void setup(){
  Serial.begin(115200);

  Mirf.spi = &MirfHardwareSpi; //Set the SPI Driver
  Mirf.init(); //Setup pins / SPI
  
  Mirf.setRADDR((byte *)"buzzz"); //Configure reciving address
  Mirf.payload = sizeof(unsigned long); //Set the payload length
  Mirf.configRegister(EN_AA,0x00);  //Disable auto ack
  Mirf.config();
  
  pinMode(led, OUTPUT);
  pinMode(buzzer, OUTPUT);
  pinMode(button, INPUT);
  
  set_sleep_mode(SLEEP_MODE_PWR_DOWN);
  sleep_enable();
  Serial.println("Buzzer Ready..."); 
}

void loop(){
  byte data[Mirf.payload];
  unsigned long time = millis();
  
  if(!Mirf.isSending() && Mirf.dataReady()) //If a packet has been recived => we can't buzz
  {
    Mirf.getData(data); //Get load the packet into the buffer
    delay(3000); // Wait for 3 second
    Serial.println("I was Buzzed");
    winner=false;
  }

  if(winner)
  {
    winner=false;
    Mirf.setTADDR((byte *)"buzzz");
    Mirf.send((byte *)&time); // Send something to prevent other buzzer that we are first
    Serial.println("I Buzzzzzed"); 
    digitalWrite(led, HIGH);   // turn the LED on (HIGH is the voltage level)
    digitalWrite(buzzer, HIGH);
    delay(400);               // wait 
    digitalWrite(led, LOW);    // turn the LED off by making the voltage LOW
    digitalWrite(buzzer, LOW);
    delay(400);               // wait
    digitalWrite(led, HIGH);   // turn the LED on (HIGH is the voltage level)
    delay(400);               // wait 
    digitalWrite(led, LOW);    // turn the LED off by making the voltage LOW
    delay(400);               // wait
    digitalWrite(led, HIGH);   // turn the LED on (HIGH is the voltage level)
    delay(400);               // wait 
    digitalWrite(led, LOW);    // turn the LED off by making the voltage LOW
    delay(400);               // wait
    digitalWrite(led, HIGH);   // turn the LED on (HIGH is the voltage level)
    delay(400);               // wait 
    digitalWrite(led, LOW);    // turn the LED off by making the voltage LOW
  }  
    
  /* Finish - night night. */
  toSleep();  
}

